==> pitivi_2020.09.2.orig.tar.xz: pitivi-2020.09.2/docs/index.md <==
---
title: Pitivi
...

# Pitivi development website

This is the documentation for **planning/contributing** to [Pitivi], the
Free and Open Source video editor based on GStreamer. If you're looking
for documentation on how to *use* Pitivi, check out our [User's Manual]
(also available directly inside the application)!

To edit the website edit the markdown files in our git repo in the
`docs/` and follow our [developer instructions].

  [Pitivi]: http://www.pitivi.org
  [User's Manual]: http://pitivi.org/manual/
  [developer instructions]: HACKING.md

# We need your help

See the [Contributing](http://www.pitivi.org/?go=contributing) page
on the website for what you can contribute, and “Why contribute to
Pitivi?”.

-   [Goals](Goals.md) ― mission statement, vision
-   [Roadmap](Roadmap.md) ― long-term plans
-   [Architecture](Architecture.md) ― Where does Pitivi fit? What
    are all those components?


## Getting started

-   [Tasks for newcomers](https://gitlab.gnome.org/GNOME/pitivi/issues?label_name%5B%5D=4.+Newcomers)
-   Setting up the [development environment](HACKING.md)
-   The [test suite](Testing.md)
-   [Git](Git.md)

## Ways to communicate

-   [Reporting bugs](Bug_reporting.md)
-   IRC: [\#pitivi](irc://irc.freenode.net/pitivi) on irc.freenode.net
-   Our [Twitter](https://twitter.com/pitivi) account. Do *not* report bugs
    there, use our bug tracker instead!
-   [The people](The_people.md) (who does what)

# Random stuff

-   [Project history](Project_history.md) ― how did we get here
-   [Current events](Current_events.md) ― releases, meetings,
    talks ... See also the [planet](http://www.pitivi.org/planet) for
    news about the project.
-   [Why Python?](design/Why_python.md)
-   [Praise](Praise.md) ― Some of the praises and positive feedback
-   [Google Summer of Code](Google_Summer_of_Code.md)

==> pitivi_2022.06.orig.tar.xz: pitivi-2022.06/docs/index.md <==
---
title: Pitivi
...

# Pitivi development website

This is the documentation for **planning/contributing** to [Pitivi], the
Free and Open Source video editor based on GStreamer. If you're looking
for documentation on how to *use* Pitivi, check out our [User's Manual]
(also available directly inside the application)!

To edit the website edit the markdown files in our git repo in the
`docs/` and follow our [developer instructions].

  [Pitivi]: https://www.pitivi.org/
  [User's Manual]: https://www.pitivi.org/manual/
  [developer instructions]: HACKING.md

# We need your help

See the [Contributing](https://www.pitivi.org/contribute/) page
on the website for what you can contribute, and “Why contribute to
Pitivi?”.

-   [Goals](Goals.md) ― mission statement, vision
-   [Roadmap](Roadmap.md) ― long-term plans
-   [Architecture](Architecture.md) ― Where does Pitivi fit? What
    are all those components?


## Getting started

-   [Tasks for newcomers](https://gitlab.gnome.org/GNOME/pitivi/issues?label_name%5B%5D=4.+Newcomers)
-   Setting up the [development environment](HACKING.md)
-   The [test suite](Testing.md)
-   [Git](Git.md)

## Ways to communicate

-   [Reporting bugs](Bug_reporting.md)
-   [Chat room](https://www.pitivi.org/contact/)
-   [The people](The_people.md) (who does what)

# Random stuff

-   [Project history](Project_history.md) ― how did we get here
-   [Current events](Current_events.md) ― releases, meetings,
    talks ... See also the [planet](https://www.pitivi.org/planet/) for
    news about the project.
-   [Why Python?](design/Why_python.md)
-   [Praise](Praise.md) ― Some of the praises and positive feedback
-   [Google Summer of Code](Google_Summer_of_Code.md)
